@@ -1,13 +1,13 @@
 #!/usr/bin/python
 # coding: UTF-8
 # Rec10 TS Recording Tools
-# Copyright (C) 2009 Yukikaze
+# Copyright (C) 2009-2010 Yukikaze
     # モジュール属性 argv を取得するため
 import rec10d
 
 def ontvsearch(ontvin):
     ret = []
-    for datum in rec10d.rec10db.select_by_ontv_chdata(ontvin):
+    for datum in rec10d.rec10db.select_by_ontv_epg_ch(ontvin):
         rett = {'bctype':datum[0], 'ontv':datum[1], 'chtxt':datum[2], 'ch':datum[3], 'csch':datum[4], 'update':datum[5]}
         ret.append(rett)
     if len(ret) == 0:
@@ -15,7 +15,7 @@ def ontvsearch(ontvin):
     return ret[0]
 def chtxtsearch(chtxtin):
     ret = []
-    for datum in rec10d.rec10db.select_by_chtxt_chdata(chtxtin):
+    for datum in rec10d.rec10db.select_by_chtxt_epg_ch(chtxtin):
         rett = {'bctype':datum[0], 'ontv':datum[1], 'chtxt':datum[2], 'ch':datum[3], 'csch':datum[4], 'update':datum[5]}
         ret.append(rett)
     if len(ret) == 0:
@@ -23,7 +23,7 @@ def chtxtsearch(chtxtin):
     return ret[0]
 def bctypesearch(bctypein):
     ret = []
-    for datum in rec10d.rec10db.select_by_bctype_chdata(bctypein):
+    for datum in rec10d.rec10db.select_by_bctype_epg_ch(bctypein):
         rett = {'bctype':datum[0], 'ontv':datum[1], 'chtxt':datum[2], 'ch':datum[3], 'csch':datum[4], 'update':datum[5]}
         ret.append(rett)
     if len(ret) == 0:
@@ -31,7 +31,7 @@ def bctypesearch(bctypein):
     return ret[0]
 def chsearch(chin):
     ret = []
-    for datum in rec10d.rec10db.select_by_ch_chdata(chin):
+    for datum in rec10d.rec10db.select_by_ch_epg_ch(chin):
         rett = {'bctype':datum[0], 'ontv':datum[1], 'chtxt':datum[2], 'ch':datum[3], 'csch':datum[4], 'update':datum[5]}
         ret.append(rett)
     if len(ret) == 0:
@@ -39,7 +39,7 @@ def chsearch(chin):
     return ret[0]
 def getall():
     ret = []
-    for datum in rec10d.rec10db.select_all_chdata():
+    for datum in rec10d.rec10db.select_all_epg_ch():
         rett = {'bctype':datum[0], 'ontv':datum[1], 'chtxt':datum[2], 'ch':datum[3], 'csch':datum[4], 'update':datum[5]}
         ret.append(rett)
     if len(ret) == 0:
@@ -50,7 +50,8 @@ def update():
     CSupdate = 0
     CS2update = 0
     BSupdate = 0
-    for datum in rec10d.rec10db.select_get_update_chdata("6"):
+    rec10d.rec10db.set_new_status("8")
+    for datum in rec10d.rec10db.select_get_update_epg_ch("6"):
         bctype = datum[0]
         if bctype == "cs1" or bctype == u"cs1":
             if CSupdate == 0:
