@@ -6,21 +6,30 @@ import os
 import os.path
 import time
 import recdblist
-def checkB25Decode(b25filepath, decodedfilepath):
+
+def checkB25Decode(b25filepath, decodedfilepath , csch):
     ret = 0
     if os.path.isfile(decodedfilepath):##tsファイルが存在している
         dtime = time.time()-os.path.getmtime(decodedfilepath)
         dtime = int(dtime)
         if dtime > 20:
-            if (compareFilesize(b25filepath, decodedfilepath, 10) and minimizeCheck(decodedfilepath, 800)):
-                ret = 1
+            if csch>0:
+                if (compareFilesize(b25filepath, decodedfilepath, 10) and minimizeCheck(decodedfilepath, 800)):
+                    ret = 1
+            else:
+                if (compareFilesize(b25filepath, decodedfilepath, 70) and minimizeCheck(decodedfilepath, 800)):
+                    ret = 1
         else:
             time.sleep(30)
             dtime = time.time()-os.path.getmtime(decodedfilepath)
             dtime = int(dtime)
             if dtime > 20:
-                if (compareFilesize(b25filepath, decodedfilepath, 10) and minimizeCheck(decodedfilepath, 800)):
-                    ret = 1
+                if csch>0:
+                    if (compareFilesize(b25filepath, decodedfilepath, 10) and minimizeCheck(decodedfilepath, 800)):
+                        ret = 1
+                else:
+                    if (compareFilesize(b25filepath, decodedfilepath, 90) and minimizeCheck(decodedfilepath, 800)):
+                        ret = 1
     #recdblist.printutf8("deleting b25 is " + str(ret))
     return ret
 def compareFilesize(pathbase, path, percentage):
