@@ -25,15 +25,20 @@ if __name__ == "__main__":
     parser.add_option("-l","--list",action="store_true",dest="list",default=False,help="File listing mode(test for -A)")
     parser.add_option("-t","--tssearch",action="store_true",dest="tssearch",default=False,help="Ts move auto search")
     parser.add_option("-T","--Tsmove",action="store_true",dest="tsmove",default=False,help="Ts auto move.")
+    parser.add_option("-S","--SeriesNum",action="store",type="string",dest="seriespath",default="",metavar="TITLE",help="Search Series Number in the path.")
+    #parser.add_option("-f","--filenumlist",action="store_true",dest="filenumlist",default=False,help="Guess Program Number.")
+
     (opts,args)=parser.parse_args(sys.argv)
-    if opts.ltitle!="":
+    if opts.ltitle!="":##-sの場合
         ltitle=unicode(opts.ltitle,'utf-8')
         sf=guess.searchFolder(ltitle, recordedpath)
         print "###MKV###"
         recdblist.printutf8(os.path.join(sf, auto_move.get_move_dest_path(ltitle,recpath,sf,".mkv")+".mkv"))
+        print "\n"
         print "###MP4###"
         recdblist.printutf8(os.path.join(sf, auto_move.get_move_dest_path(ltitle,recpath,sf,".mp4")+".mp4"))
-    elif opts.auto:
+        print "\n"
+    elif opts.auto:##-A の場合
         sa=auto_move.search_file(recpath, recordedpath, ".mkv")
         for t in sa:
             recdblist.printutf8(u"自動推測実行中-MKV")
@@ -56,7 +61,7 @@ if __name__ == "__main__":
                 auto_move.execMove(t, recpath, recordedpath,".mp4",1)
             else:
                 recdblist.printutf8(t+" can't find matching folder")
-    elif opts.list:
+    elif opts.list:##-lの場合
         sa=auto_move.search_file(recpath, recordedpath,".mkv")
         for t in sa:
             sf=guess.searchFolder(t,recordedpath)
@@ -72,7 +77,7 @@ if __name__ == "__main__":
             auto_move.execMove(etitle,recpath, recordedpath,".mkv",1)
         elif os.path.exists(os.path.join(recpath, etitle+".mp4")):
             auto_move.execMove(etitle,recpath, recordedpath,".mp4",1)
-    elif opts.tssearch:
+    elif opts.tssearch:## -tの場合
         tsmovepath=""
         try:
             tsmovepath=unicode(configreader.getpath("ts_movepath"),'utf-8')
@@ -84,10 +89,11 @@ if __name__ == "__main__":
                 sf=guess.searchFolder(t,tsmovepath,700)
                 if sf!="":
                     recdblist.printutf8(t+u" : "+os.path.join(sf, auto_move.get_move_dest_path(t, recpath,sf,".ts")+".ts"))
+                    print "\n"
             sa=auto_move.search_file(recpath, tsmovepath,".ts")
         else:
             recdblist.printutf8(u"ts_movepathが設定されていません。/etc/rec10.confを設定してください。")
-    elif opts.tsmove:
+    elif opts.tsmove:##-Tの場合
         tsmovepath=""
         try:
             tsmovepath=unicode(configreader.getpath("ts_movepath"),'utf-8')
@@ -104,4 +110,28 @@ if __name__ == "__main__":
                     auto_move.execMove(t, recpath, tsmovepath,".ts",0)
             sa=auto_move.search_file(recpath, tsmovepath,".ts")
         else:
-            recdblist.printutf8(u"ts_movepathが設定されていません。/etc/rec10.confを設定してください。")
\ No newline at end of file
+            recdblist.printutf8(u"ts_movepathが設定されていません。/etc/rec10.confを設定してください。")
+    elif opts.seriespath!="":##-Sの場合##与えられたパスにシリーズがそろっているかを調べる。
+        ss=guess.detSeriesNum(opts.seriespath)
+        for sstitle, ssv in ss.iteritems():
+            if len(ssv)>0:
+                maxt=0
+                bt=0
+                alr=[]
+                for ssi,ssiv in ssv.iteritems():
+                    alr.append(ssi)
+                    if maxt<ssi:
+                        maxt=ssi
+                alr=list(set(alr))
+                alr.sort()
+                alr.reverse()
+                nuke=""
+                for i in xrange(1,maxt+1,1):
+                    if alr.count(i)==0:
+                        nuke=nuke+str(i)+","
+                if len(nuke)==0:
+                    recdblist.printutf8(sstitle+" "+str(maxt))
+                else:
+                    recdblist.printutf8(u"**"+sstitle+" |"+str(maxt)+"| "+nuke)
+
+
