@@ -47,6 +47,7 @@ class DB_MySQL:
             epgetime DATETIME,\
             epgduplicate TINYINT DEFAULT 0,\
             epgchange TINYINT DEFAULT 0\
+            epgexp VARCHAR(200),\
             counter TINYINT DEFAULT -1\
             UNIQUE uni (type,chtxt,title,btime,deltaday)\
             )')
@@ -421,13 +422,13 @@ class DB_MySQL:
                       (type, chtxt, title, btime, etime, deltatime, deltaday, opt ,counter))
         ##db.commit()
         self.close_db(db)
-    def update_epg_timeline(self,type,chtxt,title,btime,epgbtime,epgetime,epgtitle):
+    def update_epg_timeline(self,type,chtxt,title,btime,epgbtime,epgetime,epgtitle,epgexp):
         db = self.connect_db()
         db[1].execute('\
         UPDATE timeline \
-        SET epgbtime=%s,epgetime=%s,epgtitle=%s \
+        SET epgbtime=%s,epgetime=%s,epgtitle=%s,epgexp=%s \
         WHERE type=%s AND chtxt=%s AND title=%s AND btime=%s ', \
-                      (epgbtime,epgetime,epgtitle,type, chtxt, title, btime))
+                      (epgbtime,epgetime,epgtitle,epgexp,type, chtxt, title, btime))
         ##db.commit()
         self.close_db(db)
     def update_status_change_timeline(self,type,chtxt,title,btime,epgchange):
@@ -1135,4 +1136,18 @@ class DB_MySQL:
         db[1].execute("\
         ALTER TABLE timeline ADD counter TINYINT DEFAULT -1")
         self.close_db(db)
-        self.change_version_in_status("94")
\ No newline at end of file
+        self.change_version_in_status("94")
+    def update_db_94to95(self):
+        db = self.connect_db()
+        self.drop_in_settings()
+        self.new_in_settings()
+        db[1].execute("\
+        ALTER TABLE timeline ADD epgexp VARCHAR(200)")
+        self.close_db(db)
+        self.change_version_in_status("95")
+    def update_db_95to96(self):
+        db = self.connect_db()
+        self.drop_in_settings()
+        self.new_in_settings()
+        self.close_db(db)
+        self.change_version_in_status("96")
\ No newline at end of file
