@@ -272,16 +272,12 @@ def search_keyword(key):
                             topt=status.getSettings_auto_opt()
                             recdb.recreserv(titlet,chtxtt, btimet, etimet,topt)
                     except Exception, inst:
-                        recdblist.printutf8("error occures in search_keyword_auto_jbk")
-                        recdblist.printutf8(str(type(inst)))
-                        recdblist.printutf8(str(inst))
+                        recdblist.Commonlogex("Error", "search_keyword_auto_jbk(timerec.py)", str(type(inst)),str(inst))
                 else:
                     try:
                         recdb.add_auto_keyword(chtxtt, titlet, btimet, etimet)
                     except Exception, inst:
-                        recdblist.printutf8("error occures in search_keyword")
-                        recdblist.printutf8(str(type(inst)))
-                        recdblist.printutf8(str(inst))
+                        recdblist.Commonlogex("Error", "search_keyword(timerec.py)", str(type(inst)),str(inst))
 def type_reserve(typetxt,chtxt,title,bt,et,opt):
     btime = bt.strftime("%Y-%m-%d %H:%M:%S")
     etime = et.strftime("%Y-%m-%d %H:%M:%S")
@@ -319,9 +315,7 @@ def type_reserve(typetxt,chtxt,title,bt,et,opt):
                     auto_rec.add_key("ALL", titlen,exp+" "+longexp)
                     recdblist.printutf8(u"追いかけ機能実行中: "+title+" : "+titlen+" "+btimen+" "+etimen)
                 except Exception, inst:
-                    recdblist.printutf8("Error happened in Oikake DB")
-                    recdblist.printutf8(str(type(inst)))
-                    recdblist.printutf8(str(inst))
+                    recdblist.Commonlogex("Error", "Oikake DB(timerec.py)", str(type(inst)),str(inst))
             else:
                 recdblist.printutf8(u"追いかけ機能エラー：番組データが見付かりません。")
         else:
@@ -348,18 +342,16 @@ def type_reserve(typetxt,chtxt,title,bt,et,opt):
                 recdb.rec_reclog(titlen, chtxtn, btimen, etimen, opt, exp, longexp, category)
                 auto_rec.add_key(chtxt, titlen,exp+" "+longexp)
                 auto_rec.add_key("ALL", titlen,exp+" "+longexp)
-                recdblist.printutf8(u"追いかけ機能実行中: "+title+" : "+titlen+" "+btimen+" "+etimen)
+                #recdblist.printutf8(u"追いかけ機能実行中: "+title+" : "+titlen+" "+btimen+" "+etimen)
+                recdblist.Commonlogex(u"通常", "Oikake (timerec.py)",u"追いかけ機能実行中",u"追いかけ機能実行中: "+title+" : "+titlen+" "+btimen+" "+etimen)
             except Exception, inst:
-                recdblist.printutf8("Error happened in Oikake DB")
-                recdblist.printutf8(str(type(inst)))
-                recdblist.printutf8(str(inst))
+                recdblist.Commonlogex("Error", "Oikake DB(timerec.py)", str(type(inst)),str(inst))
     elif dt <= 20 * 60:
         try:
             recdb.del_reckey(typetxtnow, title, chtxt, btime)
             recdb.rec_reckey(typetxtfinal, title, chtxt, btime, etime, opt)
         except Exception, inst:
-            recdblist.printutf8(str(type(inst)))
-            recdblist.printutf8(str(inst))
+            recdblist.Commonlogex("Error", "Oikake DB(timerec.py)", str(type(inst)),str(inst))
 def type_final(typetxt,chtxt,title,bt,et,opt):
     btime = bt.strftime("%Y-%m-%d %H:%M:%S")
     etime = et.strftime("%Y-%m-%d %H:%M:%S")
@@ -393,7 +385,7 @@ def type_final(typetxt,chtxt,title,bt,et,opt):
             newtime=bt
             newtitle=newtitle+u"_"+iff+newtime.strftime("%Y-%m-%dT%H-%M-%S")
         recdb.rec_reckey(typetxting, newtitle, chtxt, btime, etime, opt)
-        recdblist.printutf8(u"録画開始 "+newtitle+" "+btime+" "+etime)
+        recdblist.Commonlogex(u"通常","timerec.py",u"録画開始 "+newtitle+" "+btime+" "+etime)
         tv2avi.timetv2b25(recpath + "/" + newtitle + ".avi", chtxt, btime, etime, opt)
         recdb.del_reckey(typetxting, newtitle, chtxt, btime)
         if not re.search("R", opt):
@@ -444,7 +436,7 @@ def type_keyword(typetxt,chtxt,title,bt,et,opt,deltatime):
             recdb.rec_reclog(titlet, chtxtt, btimet, etimet, opt, exp,longexp,category)
             auto_rec.add_key(chtxt, titlet,exp+" "+longexp)
             auto_rec.add_key("ALL", titlet,exp+" "+longexp)
-            recdblist.printutf8(u"key "+title+u" : "+titlet+u" "+btimet+u" "+etimet)
+            recdblist.Commonlogex(u"通常","timerec.py",u"key "+title+u" : "+titlet+u" "+btimet+u" "+etimet,"")
             #except Exception, inst:
             #    recdblist.printutf8("Error happened in REC_KEYWORD DB")
             #    recdblist.printutf8(type(inst))
@@ -520,7 +512,13 @@ def type_decode_que(typetxt,chtxt,title,bt,et,opt):
                 recdb.del_reckey(typetxting, title, chtxt, btime)
                 recdb.rec_reckey(typetxtmiss, title, chtxt, btime, etime, opt)
             else:
-                ch=checker.checkB25Decode(recpath + "/" + title + ".ts.b25", recpath + "/" + title + ".ts")
+                cstch=-1
+                try:
+                    cstch=int(chdb.chtxtsearch(chtxt)['csch'])
+                except:
+                    cstch=-1
+                if cstch>-1:
+                    ch=checker.checkB25Decode(recpath + "/" + title + ".ts.b25", recpath + "/" + title + ".ts",cstch)
                 #print ch
                 if ch == 1:
                     os.remove(recpath + "/" + title + ".ts.b25")
@@ -538,11 +536,10 @@ def type_decode_que(typetxt,chtxt,title,bt,et,opt):
                 try:
                     shutil.copy(os.path.join(recpath,title+".ts"), os.path.join(movepath,title+".ts"))
                 except Exception, inst:
-                    errtxt="Error happened in type_decode_que in timerec.\n"
-                    errtxt=errtxt+"move ts error.\n"
-                    errtxt=errtxt+str(type(inst))+"\n"
-                    errtxt=errtxt+str(inst)
-                    recdblist.addlog(os.path.join(recpath,title+".ts"), errtxt, "timerec-move(Decode) error")
+                    errtxt1="move ts error.\n"
+                    errtxt2=str(type(inst))+"\n"
+                    errtxt2=errtxt2+str(inst)
+                    recdblist.Commonlogex("Error", "type_decode_que(timerec.py)", errtxt1,errtxt2)
                 recdb.rec_reckey(recdblist.REC_MOVE_END, title, chtxt, btime, etime, opt)
         else:
             recdb.del_reckey(typetxtnow, title, chtxt, btime)
@@ -587,6 +584,14 @@ def type_encode_que(typetxt,chtxt,title,bt,et,opt):
                     if not os.path.exists(paac2) and not os.path.exists(pmp32):
                         tv2avi.pentaaudio2sep(os.path.join(recpath, title+".ts"))
                 time.sleep(3)
+            elif re.search("b", opt):
+                pin = recpath + "/" + title + ".m2v"
+                if not os.path.exists(pin) or os.path.getsize(pin)<100*1000:
+                    paac2 = recpath + "/" + title + "_1.aac"
+                    pmp32 = recpath + "/" + title + "_1.mp3"
+                    if not os.path.exists(paac2) and not os.path.exists(pmp32):
+                        tv2avi.singleaudio2sep(os.path.join(recpath, title+".ts"))
+                time.sleep(3)
             makeMP4=0
             try:
                 if configreader.getenv("make_mp4")=="1":
@@ -652,11 +657,10 @@ def type_encode_que(typetxt,chtxt,title,bt,et,opt):
                     elif os.path.exists(os.path.join(recpath,title+".mkv")):
                         shutil.copy(os.path.join(recpath,title+".mkv"), os.path.join(movepath,title+".mkv"))
                 except Exception, inst:
-                    errtxt="Error happened in type_encode_que in timerec.\n"
-                    errtxt=errtxt+"move mkv/mp4 error.\n"
-                    errtxt=errtxt+str(type(inst))+"\n"
-                    errtxt=errtxt+str(inst)
-                    recdblist.addlog(os.path.join(recpath,title+".ts"), errtxt, "timerec-move(Encode) error")
+                    errtxt1="move mkv/mp4 error."
+                    errtxt2=str(type(inst))+"\n"
+                    errtxt2=errtxt2+str(inst)
+                    recdblist.Commonlogex("Error", "type_encode_que(timerec.py)", errtxt1,errtxt2)
                 recdb.rec_reckey(recdblist.REC_MOVE_END, title, chtxt, btime, etime, opt)
             recdb.rec_reckey(typetxtfin, title, chtxt, btime, etime, opt)
             sys.exit()
