@@ -61,13 +61,17 @@ def ts2x264(pin, pout, opts):#sizeは"HD"か"SD"
         encode_ffmpeg(pin,pout,size,is24fps,quality,crf)
     elif re.search("5",opts):
         encode_ffmpeg(pin,pout,size,is24fps,quality,crf)
+    elif re.search("b",opts):
+        try:
+            tm2v=pin.replace(".ts",".m2v")
+            encode(tm2v, pout,size,is24fps,quality,crf)
+        except Exception, inst:
+            recdblist.Commonlogex("Error", "ts2x264(ts2x264.py)", str(type(inst)), str(inst))
     else:
         try:
             encode(pin, pout,size,is24fps,quality,crf)
         except Exception, inst:
-            recdblist.printutf8("error occures in ts2x264.py encode")
-            recdblist.printutf8(str(type(inst)))
-            recdblist.printutf8(str(inst))
+            recdblist.Commonlogex("Error", "ts2x264(ts2x264.py)", str(type(inst)), str(inst))
 def encode(pin,pout,size,is24fps,quality,crf):
     mencoder=configreader.getpath("mencoder")
     x264=configreader.getpath("x264")
@@ -82,6 +86,14 @@ def encode(pin,pout,size,is24fps,quality,crf):
     x264preset=""
     x264tune=""
     x264_bitrate="5000"
+    x264_thread="auto"
+    try:
+        xtt=configreader.getenv("x264_thread")
+        xtt=int(xtt)
+        if xtt>0:
+            x264_thread=str(xtt)
+    except:
+        x264_thread="auto"
     x264_addline=configreader.getenv("x264_addline")
     if is24fps==1:
         ofps="-ofps 24000/1001"
@@ -141,18 +153,16 @@ def encode(pin,pout,size,is24fps,quality,crf):
     streampath=os.path.join(os.path.dirname(pin),str(random.randint(10000, 999999)))
     os.system(u"mkfifo "+streampath)
     encexe=mencoder+u" \""+pin+u"\" -vfm ffmpeg -quiet -sws 9 "+encvf+u",format=i420 "+fps+" "+ofps+" -oac mp3lame -ovc raw -of rawvideo -o \""+streampath+"\" &"
-    encexe=encexe+u" nice -n 19 "+x264+" "+x264crf+u" "+x264_addline+u"  --threads auto"+x264profile+x264preset+" "+x264tune+" "+x264fps+" -o \""+pout+"\" "+streampath+" "+x264streamsize
+    encexe=encexe+u" nice -n 19 "+x264+" "+x264crf+u" "+x264_addline+u"  --threads "+x264_thread+" "+x264profile+x264preset+" "+x264tune+" "+x264fps+" -o \""+pout+"\" "+streampath+" "+x264streamsize
     encexe=u"nice -n 19 " +encexe
     recdblist.printutf8(encexe)
-    txt=txt+"Cmd : "+encexe+"\n"
-    txtt=""
+    txt=""
     try:
-        txtt=unicode(commands.getoutput(encexe.encode('utf-8')),'utf-8')
+        txt=unicode(commands.getoutput(encexe.encode('utf-8')),'utf-8')
     except:
         ""
     os.system("rm "+streampath)
-    txt=txt+txtt
-    recdblist.addlog( pin, txt, "mencoder-log")
+    recdblist.addCommandLog(pin, u"Mencoder", encexe, txt)
 
 def encode_ffmpeg(pin,pout,size,is24fps,quality,crf):
     """
@@ -166,6 +176,14 @@ def encode_ffmpeg(pin,pout,size,is24fps,quality,crf):
     x264preset=""
     x264tune=""
     x264_bitrate="2500"
+    x264_thread="auto"
+    try:
+        xtt=configreader.getenv("x264_thread")
+        xtt=int(xtt)
+        if xtt>0:
+            x264_thread=str(xtt)
+    except:
+        x264_thread="auto"
     x264_addline=configreader.getenv("x264_addline")
     if size == "HD":
         s = "-s 1280x720 "
@@ -215,16 +233,13 @@ def encode_ffmpeg(pin,pout,size,is24fps,quality,crf):
     txt=""
     os.environ['LANG']="ja_JP.UTF-8"
     exe=ffmpeg+u" -y -i \""+pin+"\" -vsync 400 -vcodec rawvideo -pix_fmt yuv420p "+s+fps+"-deinterlace -an -f rawvideo - |"
-    exe=exe+u" nice -n 19 "+x264+" "+x264crf+u" "+x264_addline+u" --threads auto "+x264profile+x264preset+" "+x264tune+" "+x264fps+" -o \""+pout+"\" - "+x264streamsize
-    txt=txt+"Cmd : "+exe+"\n"
+    exe=exe+u" nice -n 19 "+x264+" "+x264crf+u" "+x264_addline+u" --threads "+x264_thread+" "+x264profile+x264preset+" "+x264tune+" "+x264fps+" -o \""+pout+"\" - "+x264streamsize
     exe = "nice -n 19 " + exe
-    txt=txt+"Cmd : "+exe+"\n"
-    txtt=""
+    txt=""
     recdblist.printutf8(exe)
     try:
-        txtt=unicode(commands.getoutput(exe.encode('utf-8')),'utf-8')
+        txt=unicode(commands.getoutput(exe.encode('utf-8')),'utf-8')
     except:
         ""
-    txt=txt+txtt
-    recdblist.addlog( pin, txt, "dual audio ffmpeg-log")
+    recdblist.addCommandLog(pin, u"FFmpeg動画エンコード", exe, txt)
     
\ No newline at end of file
