@@ -39,11 +39,12 @@ def timetv2b25(pout, chtxt, btime, etime, opt):
     tsout = extt[0]
     tnow = datetime.datetime.now()
     wt = bt-tnow
-    waitt = wt.seconds-5
-    time.sleep(waitt)
+    waitt = wt.seconds
+    if waitt>0:
+        time.sleep(waitt)
     tnow = datetime.datetime.now()
     dt = et-tnow
-    rectime = dt.seconds-10
+    rectime = dt.seconds-5
     rectime = str(rectime)
     tv2ts.tv2b25ts(tsout + ".ts.b25", chdb.chtxtsearch(chtxt)['ch'], rectime)
 def b252ts(pout, chtxt, btime, etime, opt):
@@ -58,6 +59,7 @@ def b252ts(pout, chtxt, btime, etime, opt):
         aviin = pout + ".ts"
         dualaudio = 0
         pentaaudio = 0
+        singleaudiosplit = 0
         if re.search("5", opt):
             pentaaudio = 1
         if re.search("d", opt):
@@ -68,14 +70,16 @@ def b252ts(pout, chtxt, btime, etime, opt):
             dualaudio = 1
         elif re.search(u'\(二\)', pout):
             dualaudio = 1
+        elif re.search("b",opt):
+            singleaudiosplit = 1
         if dualaudio == 1:
             dualaudio2sep(aviin,"167")
         if pentaaudio == 1:
             pentaaudio2sep(aviin)
+        if singleaudiosplit ==1:
+            singleaudio2sep(aviin)
     except Exception, inst:
-        recdblist.printutf8("Error happened in b252ts in tv2avi")
-        recdblist.printutf8(str(type(inst)))
-        recdblist.printutf8(str(inst))
+        recdblist.Commonlogex("Error", "b252ts(tv2avi.py)", str(type(inst)), str(inst))
     status.changeB25Decoding(-1)
 def ts2avi(pin, pout, opt):
     status.changeEncoding(1)
@@ -95,42 +99,22 @@ def ts2raw(pin, pout, opt):
         recdblist.printutf8(str(type(inst)))
         recdblist.printutf8(str(inst))
     status.changeEncoding(-1)
-def dualaudiots2avi(pin, pout):
-    bontsdemux = configreader.getpath('bontsdemux')
-    bonpin = "Z:\\" + pin[1:]
-    outf = os.path.splitext(pin)[0]
-    bonpout = "Z:\\" + outf[1:]
-    xvfb = configreader.getpath('xvfb-run')
-    logpath=pin.replace("ts","log")
-    exe = 'wine ' + bontsdemux + " -i \"" + bonpin + "\" -delay 167 -nd -sound 0 -o \"" + bonpout + "\" -start -quit"
-    #recdblist.printutf8(exe)
-    exe = xvfb + ' -a ' + exe
-    recdblist.printutf8(exe)
-    os.system(exe.encode('utf-8'))
-    ffpin1 = pin.replace("ts", "wav")
-    ffpin2 = pin.replace("ts", "m2v")
-    exe = "ffmpeg -y  -i \'" + ffpin1 + "\' -i \'" + ffpin2 + "\' -r 29.97 -vsync 200 -vcodec copy -acodec libmp3lame -async 200 -ab 128k -f avi  \'" + pout + "\'"
-    recdblist.printutf8(exe)
-    #commands.getoutput(exe)
-    os.system(exe.encode('utf-8'))
-    os.remove(ffpin1)
-    os.remove(ffpin2)
 def dualaudio2sep(pin, delay):
     """
     delay is string
     """
+    xvfb = configreader.getpath('xvfb-run')
     bontsdemux = configreader.getpath('bontsdemux')
     wine = configreader.getpath('wine')
-    xvfb = configreader.getpath('xvfb-run')
     bonpin = "Z:\\" + pin[1:]
     outf = os.path.splitext(pin)[0]
     bonpout = "Z:\\" + outf[1:]
     exe = wine + ' ' + bontsdemux + " -i \"" + bonpin + "\" -delay " + delay + " -nd -sound 1 -o \"" + bonpout + "\" -start -quit"
-    exe = xvfb + ' -a ' + exe
     recdblist.printutf8(exe)
+    exe = xvfb + ' -a ' + exe
     txt=commands.getoutput(exe.encode('utf-8'))
     try:
-        recdblist.addlog(pin, txt, "dualaudio-sep1 BontsDemux")
+        recdblist.addCommandLog(pin, u"BonTsDemux 第一音声取り出し", exe, txt)
     except:
         ""
     ffpin = pin.replace(".ts", "")
@@ -141,11 +125,11 @@ def dualaudio2sep(pin, delay):
     ffpout3 = ffpin + ".m2v"
     shutil.move(ffpin1, ffpout1)
     exe = 'wine ' + bontsdemux + " -i \"" + bonpin + "\" -delay " + delay + " -nd -sound 2 -encode Demux\(wav\) -o \"" + bonpout + "\" -start -quit"
-    exe = xvfb + ' -a ' + exe
     recdblist.printutf8(exe)
+    exe = xvfb + ' -a ' + exe
     txt=commands.getoutput(exe.encode('utf-8'))
     try:
-        recdblist.addlog(pin, txt, "dualaudio-sep1 BontsDemux")
+        recdblist.addCommandLog(pin, u"BonTsDemux 第二音声取り出し", exe, txt)
     except:
         ""
     #os.system(exe)
@@ -182,7 +166,7 @@ def pentaaudio2sep(pin):
     recdblist.printutf8(exe)
     txt=commands.getoutput(exe.encode('utf-8'))
     try:
-        recdblist.addlog(pin, txt, "pentaaudio-sep1 BontsDemux")
+        recdblist.addCommandLog(pin, u"BonTsDemux5.1ch 第一音声取り出し", exe, txt)
     except:
         ""
     ffpin = pin.replace(".ts", "")
@@ -192,11 +176,10 @@ def pentaaudio2sep(pin):
     ffpout2 = ffpin + "_2.aac"
     shutil.move(ffpin1, ffpout1)
     exe = "ffmpeg -i '"+pin+"' -vn -f aac -acodec copy '"+ffpout2+"'"
-    exe = xvfb + ' -a ' + exe
     recdblist.printutf8(exe)
     txt=commands.getoutput(exe.encode('utf-8'))
     try:
-        recdblist.addlog(pin, txt, "pentaaudio-sep2(raw aac) ffmpeg")
+        recdblist.addCommandLog(pin, u"FFmpeg 5.1ch 第二音声(raw AAC)取り出し", exe, txt)
     except:
         ""
     ffpout21=ffpout1.replace(".wav",".mp3")
@@ -217,7 +200,7 @@ def pentaaudio2sep(pin):
         recdblist.printutf8(exe)
         txt=commands.getoutput(exe.encode('utf-8'))
         try:
-            recdblist.addlog(pin, txt, "pentaaudio-sep Downmix (5.1ch error) BontsDemux")
+            recdblist.addCommandLog(pin, u"BonTsDemux 修正版第二音声(2chDownmix)取り出し", exe, txt)
         except:
             ""
         shutil.move(ffpin1, ffpout1)
@@ -228,36 +211,51 @@ def pentaaudio2sep(pin):
             tv2audio.wav2mp3_lame(ffpout1, ffpout21)
         time.sleep(3)
     ffpout21=ffpout1.replace(".wav",".aac")
-    if os.path.exists(ffoput21):
+    if os.path.exists(ffpout21):
         if os.path.getsize(ffpout21)>10*1000*1000:
             os.remove(ffpout1)
-def pentaaudiots2avi(pin, pout):
+
+def singleaudio2sep(pin):
     bontsdemux = configreader.getpath('bontsdemux')
-    bonpin = "Z:\\" + pin[1:]
+    wine = configreader.getpath('wine')
     xvfb = configreader.getpath('xvfb-run')
+    bonpin = "Z:\\" + pin[1:]
     outf = os.path.splitext(pin)[0]
     bonpout = "Z:\\" + outf[1:]
-    exe = 'wine ' + bontsdemux + " -i \"" + bonpin + "\" -delay 167 -nd -sound 3 -o \"" + bonpout + "\" -start -quit"
+    exe = wine + ' ' + bontsdemux + " -i \"" + bonpin + "\" -delay 167 -nd -sound 0 -o \"" + bonpout + "\" -start -quit"
     exe = xvfb + ' -a ' + exe
     recdblist.printutf8(exe)
-    txt=u"Cmd : "+exe+"\n"
-    txt=txt+commands.getoutput(exe.encode('utf-8'))
-    recdblist.addlog(pin, txt, "5.1ch audio Demux log")
+    txt=commands.getoutput(exe.encode('utf-8'))
+    try:
+        recdblist.addCommandLog(pin, u"BonTsDemux 音声(wav化)取り出し", exe, txt)
+    except:
+        ""
+    ffpin = pin.replace(".ts", "")
     ffpin1 = pin.replace("ts", "wav")
     ffpin2 = pin.replace("ts", "m2v")
-
-
-    exe = u"ffmpeg -y  -i \"" + ffpin1 + u"\" -i \'" + ffpin2 + u"\' -r 29.97 -vsync 200 -vcodec copy -acodec libmp3lame -async 200 -ab 128k -f avi  \"" + pout + "\""
+    ffpout1 = ffpin + "_1.wav"
+    ffpout2 = ffpin + "_2.aac"
+    shutil.move(ffpin1, ffpout1)
+    exe = "ffmpeg -i '"+pin+"' -vn -f aac -acodec copy '"+ffpout2+"'"
     recdblist.printutf8(exe)
-    txt=u"Cmd : "+exe+"\n"
-    txtt=commands.getoutput(exe.encode('utf-8'))
+    txt=commands.getoutput(exe.encode('utf-8'))
     try:
-        txt=txt+txtt
+        recdblist.addCommandLog(pin, u"FFmpeg 音声(raw AAC)取り出し", exe, txt)
     except:
-        txt=txt+"skip logging (not UTF-8)"
-    recdblist.addlog(pin, txt, "5.1ch audio Mux log")
-    if os.path.exists(pout):
-        if os.path.getsize(pout)>100*1000:
-            os.remove(ffpin1)
-            os.remove(ffpin2)
-
+        ""
+    ffpout21=ffpout1.replace(".wav",".mp3")
+    useNero=0
+    try:
+        if configreader.getpath("useNeroAAC")=="1" and os.path.exists(configreader.getpath("NeroAAC")):
+            useNero=1
+    except:
+        useNero=0
+    if useNero==1:
+        ffpout21=ffpout1.replace(".wav",".aac")
+        tv2audio.wav2aac_nero(ffpout1, ffpout21)
+    else:
+        tv2audio.wav2mp3_lame(ffpout1, ffpout21)
+    ffpout21=ffpout1.replace(".wav",".aac")
+    if os.path.exists(ffpout21):
+        if os.path.getsize(ffpout21)>10*1000*1000:
+            os.remove(ffpout1)
\ No newline at end of file
