@@ -29,9 +29,7 @@ def tv2ts(pout, ch, csch, time):
     try:
         tv2b25ts(pout + ".b25", ch, time)
     except Exception, inst:
-        recdblist.printutf8("error occures in tv2ts.py tv2ts")
-        recdblist.printutf8(str(type(inst)))
-        recdblist.printutf8(str(inst))
+        recdblist.Commonlogex(u"Error",u"tv2ts(tv2ts.py)", str(type(inst)),str(inst))
     if len(ch) > 2:#BS/CSは100とかCS??とかなので3文字以上
         status.changeBSCSRecording(-1)
     else:
@@ -83,11 +81,10 @@ def tv2b25ts(pout, ch, time):
     try:
         doexe = exe + ' ' + ch + ' ' + time + ' \'' + pout + '\''
         recdblist.printutf8(doexe)
-        recdblist.addlog(pout, unicode(commands.getoutput(doexe.encode('utf-8')),'utf-8'), u"recpt1-log")
+        recdblist.addlog(pout, doexe, u"recpt1ログ-コマンド")
+        recdblist.addlog(pout, unicode(commands.getoutput(doexe.encode('utf-8')),'utf-8'), u"recpt1ログ-詳細")
     except Exception, inst:
-        recdblist.printutf8("error occures in tv2ts.py tv2b25ts")
-        recdblist.printutf8(str(type(inst)))
-        recdblist.printutf8(str(inst))
+        recdblist.Commonlogex(u"Error",u"tv2b25ts(tv2ts.py)", str(type(inst)),str(inst))
     if len(ch) > 2:#BS/CSは100とかCS??とかなので3文字以上
         status.changeBSCSRecording(-1)
     else:
@@ -103,22 +100,21 @@ def b252tsmix(pin, pout):
             try:
                 exe = configreader.getpath('b25_env')+" && "
             except:
-                recdblist.printutf8(u"b25_remoteがオンになっていますが、b25_envが設定されていないかコメントアウトされています。")
+                inst=u"b25_remoteがオンになっていますが、b25_envが設定されていないかコメントアウトされています。"
+                recdblist.Commonlogex(u"Error",u"b252tsmix(tv2ts.py)", "",inst)
         exe = exe + "nice -n 17 " + configreader.getpath('b25')
         doexe = exe + u' \"' + pin + u'\" \"' + pout + u'\"'
         recdblist.printutf8(doexe)
         txt = unicode(commands.getoutput(doexe.encode('utf-8')),'utf-8')
-        recdblist.addlog(pin, txt, u"b25-log")
+        recdblist.addlog(pin, doexe, u"b25ログ-コマンド")
+        recdblist.addlog(pin, txt, u"b25ログ-詳細")
 def tsmix2ts(pin, pout, csch):#csch=0ならcsの処理をしない
-    """if csch==0:
-        shutil.move(pin,pout)
-    else:"""
     doexe = configreader.getpath("tssplitter") + " \""+ pin + "\" \""+ pout + "\" " + str(csch)
     doexe = "nice -n 18 " + doexe
     os.environ['LANG']="ja_JP.UTF-8"
     txt = unicode(commands.getoutput(doexe.encode('utf-8')),'utf-8')
-    txt = doexe+"\n\n"+txt
-    recdblist.addlog(pin, txt, "tssplit-log")
+    recdblist.addlog(pin, doexe, u"TsSplitログ-コマンド")
+    recdblist.addlog(pin, txt, u"TsSplitログ-詳細")
     time.sleep(1)
     if os.access(pout, os.F_OK) and os.path.getsize(pout)>10*1000*1000:
         os.remove(pin)
