@@ -30,7 +30,7 @@ use Sort::Naturally;
 ################ バージョン定義 ################
 
 
-my $rectool_version = 94;
+my $rectool_version = 96;
 
 
 ################ 初期化ここから ################
@@ -115,7 +115,7 @@ if ( !$auth ) {
 	goto end;
 }
 
-if ( not $rec10_version != $rectool_version ) {
+if ( $rec10_version != $rectool_version ) {
 	$HTML .= qq {<div style="font-size: 200%; font-weight: bold; color: red">\n};
 
 	if ( $rec10_version > $rectool_version ) {
@@ -235,7 +235,8 @@ EOM
 	$forward_order = $order eq 'btime' ? '' : '&amp;order=id';
 
 	my $ary_ref = $dbh->selectall_arrayref(
-		"SELECT id, type, epg_ch.chtxt, epg_ch.ontv, epg_ch.chname, title, btime, etime, opt, deltaday, deltatime 
+		"SELECT id, type, epg_ch.chtxt, epg_ch.ontv, epg_ch.chname, title, btime, etime, opt, deltaday, deltatime, 
+		epgtitle, epgbtime, epgetime, epgexp, epgduplicate, epgchange, counter 
 		FROM timeline 
 		INNER JOIN epg_ch ON timeline.chtxt = epg_ch.chtxt 
 		ORDER BY $order");
@@ -256,6 +257,7 @@ EOM
 	$HTML .= qq {<th>オプション</th>\n};
 	$HTML .= qq {<th>dd</th>\n};
 	$HTML .= qq {<th>dt</th>\n};
+	$HTML .= qq {<th>残り</th>\n};
 	$HTML .= qq {</tr>\n};
 	foreach my $line ( @{ $ary_ref } ) {
 
@@ -277,11 +279,12 @@ EOM
 		my $btime = $unix_6->strftime( '%Y%m%d%H%M%S' );
 		my $etime = $unix_7->strftime( '%Y%m%d%H%M%S' );
 		if ( $extra and $line->[1] =~ /^search_|^reserve_/ ) {
-			my @ary = $dbh->selectrow_array(
-				"SELECT title, exp FROM epg_timeline 
-				WHERE channel = '$line->[3]' 
-				AND start = '$btime' 
-				AND stop  = '$etime' ");
+#			my @ary = $dbh->selectrow_array(
+#				"SELECT title, exp FROM epg_timeline 
+#				WHERE channel = '$line->[3]' 
+#				AND start = '$btime' 
+#				AND stop  = '$etime' ");
+			my @ary = ( $line->[11], $line->[14] );
 
 			if ( $ary[0] ) {
 				$ary[0] =~ s/無料≫//;
@@ -297,11 +300,11 @@ EOM
 					$ary[0] = '説明';
 				}
 
-				$line->[11] = qq {<div style="float: right; cursor: help" title="$ary[1]">$ary[0]</div>};
+				$line->[5_2] = qq {<div style="float: right; cursor: help" title="$ary[1]">$ary[0]</div>};
 			}
 			else {
 				my $href    = qq {<a href="rectool.pl?mode=edit&amp;id=$line->[0]&amp;suggest=auto">自動検索</a>};
-				$line->[11] = qq {<span style="float: right; color: #FF0000">■$href■</span>};
+				$line->[5_2] = qq {<span style="float: right; color: #FF0000">■$href■</span>};
 			}
 		}
 
@@ -320,16 +323,16 @@ EOM
 		}
 
 		$line->[5] = qq {<a href="rectool.pl?mode=edit&amp;id=$line->[0]">$line->[5]</a>};
-#		$line->[5] = qq {<div style="float: left">$line->[5]</div>} if ( $line->[11] );
+#		$line->[5] = qq {<div style="float: left">$line->[5]</div>} if ( $line->[5_2] );
 		$HTML .= qq {<tr align="center">\n};
 		$HTML .= qq {<td><input type="checkbox" name="id" value="$line->[0]"></td>\n};
 		$HTML .= qq {<td>$line->[0]</td>\n};
 		$HTML .= qq {<td>$type</td>\n};
 		$HTML .= qq {<td><a href="rectool.pl?mode=program&amp;chtxt=$line->[2]">$line->[2]</a></td>\n};
-		$HTML .= qq {<td align="left" style="white-space: normal">$line->[5]$line->[11]</td>\n};
+		$HTML .= qq {<td align="left" style="white-space: normal">$line->[5]$line->[5_2]</td>\n};
 		$HTML .= qq {<td>$begin</td>\n<td>$end</td>\n};
 		$HTML .= qq {<td>$hr$diff</td>\n};
-		$HTML .= qq {<td>$line->[8]</td>\n<td>$line->[9]</td>\n<td>$line->[10]</td>\n};
+		$HTML .= qq {<td>$line->[8]</td>\n<td>$line->[9]</td>\n<td>$line->[10]</td>\n<td>$line->[17]</td>\n};
 		$HTML .= qq {</tr>\n};
 	}
 	$HTML .= qq {</table>\n};
@@ -719,6 +722,7 @@ EOM
 	$HTML .= qq {隔日周期\n<input type="text" name="deltaday" value="$deltaday" maxlength=2  size=2 >\n};
 	$HTML .= qq {時刻誤差\n<input type="text" name="deltatime" value="$deltatime" maxlength=2  size=2 >\n};
 	$HTML .= qq {オプション\n<input type="text" name="opt" value="$opt">\n};
+	$HTML .= qq {回数\n<input type="text" name="counter" value="$counter" size=2 >\n};
 	$HTML .= qq {<input type="submit" name="update" value="更新">\n</form>\n};
 }
 
@@ -749,19 +753,20 @@ if ( $mode eq 'change' ) {
 		$deltaday  = $q->param( 'deltaday' );
 		$deltatime = $q->param( 'deltatime' );
 		$opt       = $q->param( 'opt' );
+		$counter   = $q->param( 'counter' );
 		$id        = $id[0];
 		if ( $id ) {
 			$dbh->do( 
 				"UPDATE timeline SET type = '$type', chtxt = '$chtxt', title = '$title', 
 				btime = '$begin', etime = '$end', 
-				deltaday = '$deltaday', deltatime = '$deltatime', opt = '$opt' 
+				deltaday = '$deltaday', deltatime = '$deltatime', opt = '$opt', counter = '$counter' 
 				WHERE id = '$id'" 
 			);
 		}
 		else {
 			$dbh->do( 
-				"INSERT INTO timeline ( type, chtxt, title, btime, etime, deltaday, deltatime, opt ) 
-				VALUES ( '$type', '$chtxt', '$title', '$begin', '$end', '$deltaday', '$deltatime', '$opt' )" 
+				"INSERT INTO timeline ( type, chtxt, title, btime, etime, deltaday, deltatime, opt, counter ) 
+				VALUES ( '$type', '$chtxt', '$title', '$begin', '$end', '$deltaday', '$deltatime', '$opt', '$counter' )" 
 			);
 		}
 		$HTML .= "更新しました。<br>\n5秒後に予約確認画面に移動します。<br>\n";
@@ -911,6 +916,7 @@ if ( $mode eq 'reserve' ) {
 		$title =~ s/＜.*＞//;
 		$title =~ s/（.*）//;
 		$title =~ s/\[新\]//;
+		$title =~ s/無料≫//;
 		$title =~ s/\s*$//;
 		$deltaday  = 7;
 		$deltatime = 3;
@@ -992,8 +998,9 @@ if ( $mode eq 'list' ) {
 	$HTML =~ s/%HTML_TITLE_OPT%/ - List/;
 	$HTML .= qq {<div>\n};
 
-	my $recording = $cfg->param( 'path.recpath' );
-	my $recorded  = $cfg->param( 'path.recorded' );
+	my $recording   = $cfg->param( 'path.recpath' );
+	my $ts_movepath = $cfg->param( 'path.ts_movepath' );
+	my $recorded    = $cfg->param( 'path.recorded' );
 
 	if ( $mode_sub eq 'log' ) {
 		my $title = $q->param( 'title' );
@@ -1014,6 +1021,7 @@ if ( $mode eq 'list' ) {
 	}
 	if ( !$mode_sub || $mode_sub eq 'old' ) {
 		$HTML .= "録画後のファイル一覧<br>\n";
+		&simple_list( $ts_movepath );
 		&simple_list( $recorded );
 	}
 
@@ -1403,6 +1411,9 @@ if ( $mode eq 'recognize' ) {
 	$HTML .= qq {<textarea name="text" cols=40 rows=4>\n$text</textarea>\n};
 	$HTML .= qq {<input type="submit" value="実行">\n</div>\n</form>\n};
 
+	my @ch_list = @{ $dbh->selectcol_arrayref( "SELECT chtxt FROM epg_ch" ) };
+	my $ch_list = join '|', @ch_list;
+
 	if ( $text ) {
 		my ( $year, $month, $day );
 		my ( $hour, $minute );
@@ -1422,6 +1433,9 @@ if ( $mode eq 'recognize' ) {
 			( $year, $month, $day ) = @date if ( $date[0] && $date[1] && $date[2] );
 			( $hour, $minute )      = @time if ( defined $time[0] && defined $time[1] );
 			$next_day = 1 if ( $_ =~ /深夜/ );
+			my ( $ch ) = /($ch_list)/;
+			my $chtxt = $ch if ( $ch );
+
 			if ( $year && $month && $day && defined $hour && defined $minute ) {
 				my $tp = Time::Piece->strptime( "$year-$month-$day $hour:$minute", '%Y-%m-%d %H:%M' );
 				$tp += ONE_DAY if ( $next_day );
@@ -1490,6 +1504,9 @@ if ( $mode eq 'expert' ) {
 	$HTML .= qq {<hr>\n地上波録画数：$ary[0]\n衛星波録画数：$ary[1]\n解読数：$ary[2]\n縁故数：$ary[3]\n<br>\n};
 
 
+	$HTML .= qq {<hr>\nRec10 バージョン：$rec10_version\nrectool バージョン：$rectool_version\n<br>\n};
+
+
 	$HTML .= qq {<hr>\n番組表の欠落<br>\n};
 	$ary_ref = $dbh->selectall_arrayref( "SELECT chname, chtxt FROM epg_ch" );
 	foreach my $line ( @{$ary_ref} ) {
@@ -1514,6 +1531,7 @@ if ( $mode eq 'expert' ) {
 		$HTML .= qq {<pre>\n$line->[0]\n$error</pre>\n} if ( $error );
 		}
 
+
 	$ary_ref = $dbh->selectall_arrayref( 
 		"SELECT chname, chtxt, ontv, bctype, ch, csch, updatetime, status 
 		FROM epg_ch 
@@ -1768,7 +1786,7 @@ sub draw_form_opt {
 	if ( $chtxt  =~ /\Qbs-nhk-hi\E/ ) {
 		$selected{F} = 'selected';
 	}
-	elsif ( $chtxt  =~ /movieplus|nihoneiga/ ) {
+	elsif ( $chtxt  =~ /movieplus|nihoneiga|kidshd/ ) {
 		$selected{H} = 'selected';
 	}
 	elsif ( $chtxt =~ /bs-nhk/ || $bctype =~ /cs/ ) {
@@ -1793,6 +1811,8 @@ sub draw_form_opt {
 			$selected{$opt} = 'selected' if ( $opt =~ /S|L|G|H|F/ );
 			$checked {$opt} = 'checked'  if ( $opt =~ /a|h|l|d|2|5/ );
 		}
+		$checked{d} = $title =~ /\Q[二]\E|［二］|\Q(二)\E|（二）/ ? 'checked' : '';
+		$checked{5} = $title =~ /5\.1|5．1/ ? 'checked' : '';
 	}
 
 	$HTML .= qq {<select name="opt">\n};
@@ -1875,8 +1895,8 @@ sub parse_program {
 		);
 	}
 	if ( $id ) {
-		( $type, $chtxt, $title, $begin, $end, $deltaday, $deltatime, $opt ) = $dbh->selectrow_array( 
-			"SELECT type, chtxt, title, btime, etime, deltaday, deltatime, opt 
+		( $type, $chtxt, $title, $begin, $end, $deltaday, $deltatime, $opt, $counter ) = $dbh->selectrow_array( 
+			"SELECT type, chtxt, title, btime, etime, deltaday, deltatime, opt, counter 
 			FROM timeline WHERE id = '$id' " 
 		);
 		( $ontv, $chname, $bctype ) = $dbh->selectrow_array( 
